package com.zoniot.ccrc.service.impl;

import com.zoniot.ccrc.commom.exception.ServiceException;
import com.zoniot.ccrc.commom.utils.ExcelUtil;
import com.zoniot.ccrc.commom.utils.Jdk8DateUtils;
import com.zoniot.ccrc.dto.DeviceMeasuringDataDTO;
import com.zoniot.ccrc.entity.MeterReadRecord;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import com.zoniot.ccrc.dao.MeterReadRecordMapper;
import com.zoniot.ccrc.service.MeterReadRecordService;

import java.time.format.DateTimeFormatter;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import static com.google.common.collect.Lists.newArrayList;

@Service
public class MeterReadRecordServiceImpl implements MeterReadRecordService{

    @Resource
    private MeterReadRecordMapper meterReadRecordMapper;

    @Override
    public List<DeviceMeasuringDataDTO> getData(Long deviceId, Integer startDate, Integer endDate) {

        List<MeterReadRecord> list = meterReadRecordMapper.getList(deviceId,startDate,endDate);

        List<DeviceMeasuringDataDTO> result = new ArrayList<>();
        if (list != null && list.size() > 0) {
            for (MeterReadRecord record : list) {
                DeviceMeasuringDataDTO dto = new DeviceMeasuringDataDTO();
                dto.setDateTime(Jdk8DateUtils.getLocalDateTimeToDate(record.getReadTime()));
                Map<String,String> map = new HashMap<>();
                map.put("meterReading",record.getReadData());
                map.put("valveStatus",convert(record.getValveStatus()));
                map.put("meterStatusInfo",record.getMeterStatusInfo());
                dto.setMeasuringData(map);
                result.add(dto);
            }
        }
        return result;
    }

    @Override
    public void getDataExcel(Long deviceId, Integer startDate, Integer endDate, HttpServletResponse httpServletResponse) {
        List<MeterReadRecord> list = meterReadRecordMapper.getList(deviceId,startDate,endDate);
        String title = "历史数据";
        String[] rowsName = new String[]{"序号", "时间", "表盘读数", "阀门状态", "告警信息"};
        List<Object[]> dataList = newArrayList();
        Object[] objs = null;
        DateTimeFormatter df = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
        for (int i = 0; i < list.size(); i++) {
            MeterReadRecord dto = list.get(i);
            objs = new Object[rowsName.length];
            objs[0] = i;
            objs[1] = dto.getReadTime()!=null?dto.getReadTime().format(df):null;
            objs[2] = dto.getReadData();
            objs[3] = convert(dto.getValveStatus());
            objs[4] = dto.getMeterStatusInfo();

            dataList.add(objs);
        }
        ExcelUtil excelUtil = new ExcelUtil(title, rowsName, dataList);
        try {
            excelUtil.export(httpServletResponse);
        } catch (Exception e) {
            throw new ServiceException(-900, "导出异常");
        }
    }

    private String convert(Integer valveStatus){
        //0:关,1:开,2:无阀
        if(valveStatus == 0) return "关";
        if(valveStatus == 1) return "开";
        return "无阀";
    }
}
